package com.yihu.ehr.controller;

import com.ngdata.sep.EventListener;
import com.ngdata.sep.PayloadExtractor;
import com.ngdata.sep.SepModel;
import com.ngdata.sep.impl.BasePayloadExtractor;
import com.ngdata.sep.impl.SepConsumer;
import com.ngdata.sep.impl.SepModelImpl;
import com.ngdata.sep.util.zookeeper.ZkUtil;
import com.ngdata.sep.util.zookeeper.ZooKeeperItf;
import com.yihu.ehr.listener.HbaseLogListener;
import org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.hbase.HBaseConfiguration;
import org.apache.hadoop.hbase.util.Bytes;
import org.apache.kafka.common.requests.ApiVersionsResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

/**
 * Created by janseny on 2018/9/13.
 */
@RestController
@RequestMapping("/consumer")
public class ConsumerController {
    Logger log = LoggerFactory.getLogger(ConsumerController.class);

    @Value("${server.host}")
    private String localhost;
    @Value("${zookeeper.broker.address}")
    private String zookeeperHost;

    private static String subscriptionName = "logger";
    private SepConsumer sepConsumer;

    /**
     * hbase 执行动作 日志监听
     * 开启消费
     * 参数说明：
     * table 表
     * columnFamily 列族
     * columnQualifier 列限定符
     */
    @RequestMapping(value = "/start", method = RequestMethod.GET)
    public void start(
            @RequestParam(value = "table") String table,
            @RequestParam(value = "columnFamily") String columnFamily,
            @RequestParam(value = "columnQualifier") String columnQualifier
    ){
        try {
            Configuration hbaseConf = HBaseConfiguration.create();
            hbaseConf.setBoolean("hbase.replication", true);
            ZooKeeperItf zk = ZkUtil.connect(zookeeperHost, 20000);
            SepModel sepModel = new SepModelImpl(zk, hbaseConf);
            if (!sepModel.hasSubscription(subscriptionName)) {
                sepModel.addSubscriptionSilent(subscriptionName);
            }
            PayloadExtractor payloadExtractor = new BasePayloadExtractor(Bytes.toBytes(table), Bytes.toBytes(columnFamily),Bytes.toBytes(columnQualifier));//配置成参数
            HbaseLogListener hbaseLogListener = new HbaseLogListener();
            sepConsumer = new SepConsumer(subscriptionName, 5000, hbaseLogListener, 1, localhost, zk, hbaseConf,payloadExtractor);
            sepConsumer.start();
            log.debug("started");
            System.out.println("Started");
        }catch (Exception e){
            log.debug(e.getMessage());
        }
    }

    /**
     * 停止消费
     */
    @RequestMapping(value = "/stop", method = RequestMethod.GET)
    public void stop(){
        try {
            sepConsumer.stop();
            log.debug("stop");
            System.out.println("Stop");
        }catch (Exception e){
            log.debug(e.getMessage());
        }
    }

}
